@@ -8,7 +8,7 @@ from functools import partial
 import bdb
 import warnings
 from copy import deepcopy
-from typing import TYPE_CHECKING, Union, List, Callable, Tuple, Optional, Any, Sequence, Type, cast, Dict, Set
+from typing import TYPE_CHECKING, Union, List, Callable, Tuple, Optional, Any, Sequence, Type, cast, Dict, Set, Iterator
 
 from pyfileconf.basemodels.registrar import Registrar
 from pyfileconf.data.logic.convert import convert_to_empty_obj_if_necessary
@@ -29,7 +29,7 @@ from pyfileconf.plugin import manager as plugin_manager
 from pyfileconf.views.object import ObjectView
 
 if TYPE_CHECKING:
-    from pyfileconf.runner.models.interfaces import RunnerArgs, StrOrView, IterativeResults
+    from pyfileconf.runner.models.interfaces import RunnerArgs, StrOrView, IterativeResults, IterativeResult
 
 from pyfileconf.config.models.manager import ConfigManager
 from pyfileconf.pipelines.models.registrar import PipelineRegistrar
@@ -92,7 +92,8 @@ class PipelineManager:
     def __dir__(self):
         exposed_methods = [
             'run',
-            'run_iter',
+            'run_product',
+            'run_product_gen',
             'get',
             'update',
             'load',
@@ -155,8 +156,8 @@ class PipelineManager:
         else:
             return self._run_depending_on_settings(str_or_list_only)
 
-    def run_iter(self, section_path_str_or_list: 'RunnerArgs', config_updates: Sequence[Dict[str, Any]],
-                 collect_results: bool = True) -> 'IterativeResults':
+    def run_product(self, section_path_str_or_list: 'RunnerArgs', config_updates: Sequence[Dict[str, Any]],
+                    collect_results: bool = True) -> 'IterativeResults':
         """
         Run one or multiple registered functions/sections multiple times, each time
         updating the config with a combination of the passed config updates.
@@ -180,6 +181,18 @@ class PipelineManager:
         )
         return iterative_runner.run(collect_results=collect_results)
 
+    def run_product_gen(
+        self, section_path_str_or_list: 'RunnerArgs', config_updates: Sequence[Dict[str, Any]],
+    ) -> Iterator['IterativeResult']:
+        iterative_runner = IterativeRunner(
+            section_path_str_or_list,
+            config_updates,
+            base_section_path_str=self.name,
+            strip_manager_from_iv=True,
+        )
+        return iterative_runner.run_gen()
+
+
     def _run_depending_on_settings(self, section_path_str_or_list: Union[str, List[str]]) -> ResultOrResults:
         if self.auto_pdb:
             return self._run_with_auto_pdb(section_path_str_or_list)
@@ -256,7 +269,7 @@ class PipelineManager:
         :return:
         """
         section_path_str = self._get_section_path_str_from_section_path_str_or_view(section_path_str_or_view)
-        self.config.reset(section_path_str, allow_create=allow_create)
+        self.runner.reset(section_path_str, allow_create=allow_create)
 
     def reload(self) -> None:
         """
