@@ -136,16 +136,21 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
         sel = Selector()
         iv = sel.test_pipeline_manager.stuff.ExampleClass
         expected_a_result = (1, 2)
+        expected_f_value = 'woo'
         section_path = SectionPath.from_section_str_list(SectionPath(iv.section_path_str)[1:])
         pipeline_manager.update(
             a=expected_a_result,
             section_path_str=section_path.path_str
         )
         ec = sel.test_pipeline_manager.stuff.ExampleClass()
+        ec._f = expected_f_value
+        ec = sel.test_pipeline_manager.stuff.ExampleClass()
         assert ec == ExampleClass(expected_a_result)
+        assert ec._f == expected_f_value
         pipeline_manager.refresh(section_path.path_str)
         ec = sel.test_pipeline_manager.stuff.ExampleClass()
         assert ec == ExampleClass(expected_a_result)
+        assert ec._f == expected_f_value
 
     def test_config_update_by_file_for_class(self):
         self.write_example_class_to_pipeline_dict_file()
@@ -259,20 +264,29 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
         sel = Selector()
         iv = sel.test_pipeline_manager.example_class.stuff.data
         expected_a_result = (1, 2)
+        expected_f_result = 'woo'
         section_path = SectionPath.from_section_str_list(SectionPath(iv.section_path_str)[1:])
         pipeline_manager.update(
             a=expected_a_result,
             section_path_str=section_path.path_str
         )
         ec = sel.test_pipeline_manager.example_class.stuff.data
+        # TODO: setting attribute on selector should set attribute on underlying object
+        #
+        # Modify the next line in this test to `ec._f = expected_f_result` and
+        # it will show the need for this behavior
+        ec.item._f = expected_f_result
+        ec = sel.test_pipeline_manager.example_class.stuff.data
         expect_ec = ExampleClass(name='data', a=expected_a_result)
         assert ec.name == expect_ec.name
         assert ec.a == ec._a == expect_ec.a
+        assert ec._f == expected_f_result
         pipeline_manager.refresh(section_path.path_str)
         ec = sel.test_pipeline_manager.example_class.stuff.data
         expect_ec = ExampleClass(name='data', a=expected_a_result)
         assert ec.name == expect_ec.name
         assert ec.a == ec._a == expect_ec.a
+        assert ec._f == expected_f_result
 
     def test_config_update_by_file_for_specific_class_dict(self):
         self.write_example_class_dict_to_file()
